Method: Backup::Logger::Logfile::Options#enabled
- Defined in:
- lib/backup/logger/logfile.rb
#enabled ⇒ Boolean?
Enable the use of Backup’s log file.
While not necessary, as this is true by default, this may also be set on the command line using --logfile.
The use of Backup’s log file may be disabled using the command line option --no-logfile.
If --no--logfile is used on the command line, then the log file will be disabled and any setting here will be ignored.
21 22 23 |
# File 'lib/backup/logger/logfile.rb', line 21 def enabled @enabled end |